Struct pallet_saft_registry::pallet::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
Adds a new SAFT to the index and mints the amount of
IndexToken according to the record’s nav to reflect the added value of this SAFT
record.
Parameters:
asset_id: The identifier of the asset secured by the SAFT. If the asset identifying the SAFT’s asset does not exist yet, it will get created.nav: The NAV for the asset being secured by the SAFT at time of submission. This will be used to determine the amount of index token this record is worth based on the currentNAVof the index.units: Amount of assets being attested to the total value in index tokens the SAFT is worth.
The amount of token minted and awarded to the LP is determined via the current on chain
NAV of the index token and the nav of the record that was part of the associated
proposal The id that was assigned to the SAFT when it was added with add_saft.
NOTE: For the purpose of calculating the “NAV” of the index, the value
(SAFTRecord::nav) of each record is considered to be denominated in the same currency
pair as the price feeds used for the liquid assets. For example if all price feeds use a
Liquid/USD pair, then the SAFTRecord::nav would describe the USD value of the
record.
Callable by the governance committee.
Weight: O(1)
pub fn force_add_saft(
origin: OriginFor<T>,
recipient: T::AccountId,
asset_id: T::AssetId,
nav: T::Balance,
units: T::Balance
) -> DispatchResult
pub fn force_add_saft(
origin: OriginFor<T>,
recipient: T::AccountId,
asset_id: T::AssetId,
nav: T::Balance,
units: T::Balance
) -> DispatchResult
Adds saft with root origin
pub fn remove_saft(
origin: OriginFor<T>,
asset_id: T::AssetId,
saft_id: SAFTId
) -> DispatchResult
pub fn remove_saft(
origin: OriginFor<T>,
asset_id: T::AssetId,
saft_id: SAFTId
) -> DispatchResult
Removes the SAFT from the registry by purging it from the
ActiveSAFTs storage.
The change in NAV will also be reflected in the index.
Parameters:
asset_id: The identifier of the asset of the SAFTsaft_id: The id that was assigned to the SAFT when it was added withadd_saft
Callable by the governance committee.
Weight: O(1)
pub fn force_remove_saft(
origin: OriginFor<T>,
asset_id: T::AssetId,
saft_id: SAFTId,
who: T::AccountId
) -> DispatchResult
pub fn force_remove_saft(
origin: OriginFor<T>,
asset_id: T::AssetId,
saft_id: SAFTId,
who: T::AccountId
) -> DispatchResult
Removes saft assets with root origin
Called to update the Net Asset Value (NAV) associated with a SAFT record in the registry.
The NAV of a SAFT is subject to change over time, and will be
updated at regular intervals via governance proposals. Changing the
NAV of the record will also be reflected in the asset-index, because this does not
burn any index tokens but rather represents a “changed price” of the future token.
This is a noop if the given latest_nav is equal to the current nav of the SAFT.
Parameters:
asset_id: The identifier of the SAFTsaft_id: The identifier of the targetedSaftRecordwhose value should be updatedlatest_nav: The NAV for theSaftRecordidentified by theindex
Callable by the governance committee.
Weight: O(1)
pub fn convert_to_liquid(
origin: OriginFor<T>,
asset_id: T::AssetId,
location: MultiLocation
) -> DispatchResult
pub fn convert_to_liquid(
origin: OriginFor<T>,
asset_id: T::AssetId,
location: MultiLocation
) -> DispatchResult
Converts the asset secured by the SAFT into a liquid asset with the given location
Callable by the governance committee.
Weight: O(C) where C is the number of SAFTs for the asset as tracked by the
SAFTCounter.
TODO: appropriate fees
pub fn active_safts<KArg1, KArg2>(
k1: KArg1,
k2: KArg2
) -> Option<SAFTRecord<T::Balance, T::Balance>> where
KArg1: EncodeLike<T::AssetId>,
KArg2: EncodeLike<SAFTId>,
pub fn active_safts<KArg1, KArg2>(
k1: KArg1,
k2: KArg2
) -> Option<SAFTRecord<T::Balance, T::Balance>> where
KArg1: EncodeLike<T::AssetId>,
KArg2: EncodeLike<SAFTId>,
Store a mapping (AssetId, SAFTId) -> SAFTRecord
Since SAFTCounter(AssetId) stores a running counter of SAFTRecord,
this map is guaranteed to store less SAFTRecords than the asset’s
SAFTCounter. If this maps stores a None value for a SAFTId lower
than the counter, then this means the record was removed entirely.
A running counter used to determine the next SAFT id for a specific asset.
Store a mapping (AssetId) -> NAV for each SAFT
Stores the aggregated NAV of all SAFTs, which is the sum the nav of
all SAFTRecords for each asset