Type Definition pallet_saft_registry::pallet::ActiveSAFTs [−][src]
pub type ActiveSAFTs<T: Config> = StorageDoubleMap<_GeneratedPrefixForStorageActiveSAFTs<T>, Blake2_128Concat, T::AssetId, Twox64Concat, SAFTId, SAFTRecord<T::Balance, T::Balance>, OptionQuery>;Expand description
Store a mapping (AssetId, SAFTId) -> SAFTRecord
Since SAFTCounter(AssetId) stores a running counter of SAFTRecord,
this map is guaranteed to store less SAFTRecords than the asset’s
SAFTCounter. If this maps stores a None value for a SAFTId lower
than the counter, then this means the record was removed entirely.